@@ -34,8 +34,13 @@
  *
  *-----------------------------------------------------------------------------
  *
- * $Id: yeti_misc.c,v 1.11 2010/04/13 14:41:39 eric Exp $
+ * $Id: yeti_misc.c,v 1.12 2011/01/31 07:43:30 eric Exp $
  * $Log: yeti_misc.c,v $
+ * Revision 1.12  2011/01/31 07:43:30  eric
+ *  - set_alarm removed (use Yorick's "after")
+ *  - removed old stuff (it is now possible to compile with TCG=exe,
+ *    thanks to Dave Munro)
+ *
  * Revision 1.11  2010/04/13 14:41:39  eric
  *  - Changed license.
  *  - Functions that are now in Yorick have been removed.
@@ -108,9 +113,8 @@
 #endif
 
 /* Built-in functions defined in this file: */
-extern BuiltIn Y__yeti_init;
+extern BuiltIn Y_yeti_init;
 extern BuiltIn Y_mem_base, Y_mem_copy, Y_mem_peek;
-extern BuiltIn Y_set_alarm;
 extern BuiltIn Y_get_encoding;
 extern BuiltIn Y_nrefsof;
 extern BuiltIn Y_smooth3;
@@ -148,15 +152,6 @@ extern char *yHomeDir;  /* e.g., "/usr/local/lib/yorick/1.5"   */
 extern char *ySiteDir;  /* e.g., "/usr/local/share/yorick/1.5" */
 extern char *yUserPath; /* e.g., ".:~/yorick:~/Yorick"         */
 
-#ifndef PLUG_IN
-/* Yeti default's: */
-static char *default_path = (char *)0;
-static char *yeti_home = YETI_HOME;
-
-static void globalize_function(const char *name, BuiltIn *value, int quiet);
-static void append_to_default_path(const char *part1, const char *part2);
-static void set_path(int argc);
-#endif /* PLUG_IN */
 static void globalize_string(const char *name, const char *value);
 static void globalize_long(const char *name, long value);
 
@@ -167,67 +162,16 @@ static void fast_DivideZ(Operand *l, Operand *r);
 
 void Y_yeti_init(int argc)
 {
-  static int first_time = 1;
   const char *version = YETI_STRINGIFY(YETI_VERSION_MAJOR) "." \
     YETI_STRINGIFY(YETI_VERSION_MINOR) "." \
     YETI_STRINGIFY(YETI_VERSION_MICRO) YETI_VERSION_SUFFIX;
 
-  if (first_time) {
-    /* This is the first time _yeti_init has been called. */
-
-#ifndef PLUG_IN
-    /* Setup default path (for Yeti + Yorick); note that Yorick's
-       "contrib" directory is always left at the end. */
-    default_path = (yUserPath ? p_strcpy(yUserPath) : (char *)0);
-    append_to_default_path(ySiteDir, "i");
-    if (yLaunchDir && yLaunchDir[0]) {
-      int offset, length = strlen(yLaunchDir);
-      char *pathtmp = p_malloc(length + 1);
-      memcpy(pathtmp, yLaunchDir, length + 1);
-      while (length > 0 && pathtmp[length - 1] == '/') {
-	--length;
-      }
-      pathtmp[length] = 0;
-      offset = length;
-      while (offset > 0 && pathtmp[offset - 1] != '/') {
-	--offset;
-      }
-      if (strcmp(pathtmp + offset, "launch")) {
-	/* Tail of launch directory does not match "launch": assume
-	   execution from source directory and append launch directory
-	   to list of search paths. */
-	append_to_default_path(pathtmp, (char *)0);
-
-      } else {
-	/* Tail of launch directory does match "launch": assume standard
-	   installation. */
-	pathtmp[offset] = 0;
-	append_to_default_path(pathtmp, "plugins");
-	append_to_default_path(pathtmp, "i");
-      }
-      p_free(pathtmp);
-    } else {
-      append_to_default_path(yeti_home, "plugins");
-      append_to_default_path(yeti_home, "i");
-    }
-    append_to_default_path(ySiteDir, "contrib");
-
-    /* Replace built-in function 'set_path' by Yeti's version. */
-    globalize_function("set_path", set_path, 1);
-#endif /* PLUG_IN */
-
 #if USE_FASTER_DIVIDE_Z
-    /* Replace complex division by faster code. */
-    complexOps.Divide = fast_DivideZ;
+  /* Replace complex division by faster code. */
+  complexOps.Divide = fast_DivideZ;
 #endif /* USE_FASTER_DIVIDE_Z */
 
-    first_time = 0;
-  }
-
   /* Restore global variables. */
-#ifndef PLUG_IN
-  globalize_string("YETI_HOME", yeti_home);
-#endif /* not PLUG_IN */
   globalize_string("YETI_VERSION", version);
   globalize_long("YETI_VERSION_MAJOR", YETI_VERSION_MAJOR);
   globalize_long("YETI_VERSION_MINOR", YETI_VERSION_MINOR);
@@ -238,101 +182,6 @@ void Y_yeti_init(int argc)
   }
 }
 
-#ifndef PLUG_IN
-static void set_path(int argc)
-{
-  char *path;
-  if (argc < 1) path = default_path;
-  else if (argc == 1) path = YGetString(sp);
-  else { YError("set_path takes at most one argument"); path = 0; }
-  YpSetPaths(path);
-}
-
-static void append_to_default_path(const char *part1, const char *part2)
-{
-  char *ptr, *path;
-  int len;
-#define STRLEN(str) ((str) && (str)[0] ? strlen(str) : 0)
-  int len0 = STRLEN(default_path);
-  int len1 = STRLEN(part1);
-  int len2 = STRLEN(part2);
-#undef STRLEN
-
-  /* Remove trailing '/' from PART1 and PART2 */
-  while (len1 > 0 && part1[len1 - 1] == '/') --len1;
-  while (len2 > 0 && part2[len2 - 1] == '/') --len2;
-
-  /* Remove leading '/' from PART2. */
-  while (len2 > 0 && part2[0] == '/') {
-    --len2;
-    ++part2;
-  }
-
-  if (len1 <= 0 && len2 <= 0) return; /* nothing to do */
-
-  /* Append directory path to list of search pathes. */
-  len = (len0 > 0 ? len0 + 1 : 0); /* plus 1 for the ':' separator */
-  if (len1 > 0) len += len1 + 1; /* plus 1 for the '/' separator */
-  if (len2 > 0) len += len2 + 1; /* plus 1 for the '/' separator */
-  path = p_malloc(len + 1);
-  ptr = path;
-  if (len0 > 0) {
-    memcpy(ptr, default_path, len0);
-    ptr[len0] = ':';
-    ptr += len0 + 1;
-  }
-  if (len1 > 0) {
-    memcpy(ptr, part1, len1);
-    ptr[len1] = '/';
-    ptr += len1 + 1;
-  }
-  if (len2 > 0) {
-    memcpy(ptr, part2, len2);
-    ptr[len2] = '/';
-    ptr += len2 + 1;
-  }
-  path[len] = 0;
-  if (default_path) p_free(default_path);
-  default_path = path;
-}
-
-static void globalize_function(const char *name, BuiltIn *value, int quiet)
-{
-  long index = Globalize(name, 0L);
-  DataBlock *old;
-  if (globTab[index].ops == &dataBlockSym) {
-    /* Symbol currently stored in global table is a data block. */
-    old = globTab[index].value.db;
-    if (old->ops == &builtinOps) {
-      /* Previous symbol is a builtin function. */
-      if (((BIFunction *)old)->function == value) {
-	/* Nothing to do. */
-	return;
-      } else if (old->references == 0) {
-	/* Just overwrite pointer to function. */
-	((BIFunction *)old)->function = value;
-	((BIFunction *)old)->index = index;
-	return;
-      } else if (quiet) {
-	/* This is a hack to avoid printing of a warning when
-	   unreferencing a builtin function; the cost is that the memory
-	   block allocated for the builtin function is lost forever (but
-	   that's 16 bytes on a 32-bit machine). */
-	globTab[index].value.db = (DataBlock *)NewBIFunction(value, index);
-	return;
-      }
-    }
-  } else {
-    /* Symbol currently stored in global table is not a data block. */
-    old = (DataBlock *)0;
-  }
-  globTab[index].ops = &intScalar; /* in case of interrupt */
-  globTab[index].value.db = (DataBlock *)NewBIFunction(value, index);
-  globTab[index].ops = &dataBlockSym;
-  Unref(old);
-}
-#endif /* not PLUG_IN */
-
 static void globalize_string(const char *name, const char *value)
 {
   long index = Globalize(name, 0L);
@@ -609,133 +458,6 @@ static Operand *form_operand_db(Symbol *owner, Operand *op)
   return op;
 }
 
-/*---------------------------------------------------------------------------*/
-/* ALARM CALLBACK */
-
-static void check_symbol_name(const char *name);
-
-typedef struct alarm_context alarm_context_t;
-struct alarm_context {
-  alarm_context_t *next;
-  Function *task;  /* pointer to function or NULL */
-  long      index; /* index in globTab[] or -1 */
-  double    time;
-};
-
-static alarm_context_t *alarm_next = 0;
-static alarm_context_t *alarm_free = 0;
-
-static void alarm_callback(void *context);
-
-static void alarm_free_context(alarm_context_t *this)
-{
-  Function *task = this->task;
-  alarm_next = this->next;
-  this->task = 0; /* fix alloc below */
-  this->next = alarm_free;
-  /*if (task)*/ Unref(task);
-}
-
-static void alarm_callback(void *context)
-{
-  Function *task;
-  alarm_context_t *this = (alarm_context_t *)context;
-
-  if (! (task = this->task) && this->index >= 0) {
-    Symbol *sym = &globTab[this->index];
-    if (sym->ops == &dataBlockSym) {
-      int typeID = sym->value.db->ops->typeID;
-      if (typeID == T_FUNCTION || typeID == T_BUILTIN)
-	task = (Function *)sym->value.db;
-    }
-  }
-  this->task = 0;
-  alarm_free_context(this);
-  if (task) RunTaskNow(task); /* unref? */
-}
-
-static void check_symbol_name(const char *name)
-{
-  static int char_type[256], first_time = 1;
-  int i;
-  if (first_time) {
-    char_type[0] = 0;
-    for (i=1 ; i<256 ; ++i) char_type[i] = -1;
-    char_type['_'] = 1;
-    for (i='a' ; i<='z' ; ++i) char_type[i] = 1;
-    for (i='A' ; i<='Z' ; ++i) char_type[i] = 1;
-    for (i='0' ; i<='9' ; ++i) char_type[i] = 2;
-    first_time = 0;
-  }
-  if (name) {
-    unsigned char *s = (unsigned char *)name;
-    if (char_type[*s++] == 1) {
-      for (;;) {
-	if ((i = char_type[*s++]) < 0) break;
-	if (i == 0) return;
-      }
-    }
-  }
-  YError("invalid symbol's name");
-}
-
-void Y_set_alarm(int nargs)
-{
-  alarm_context_t  *this;
-  alarm_context_t  *next = alarm_next;
-  alarm_context_t **prev = &alarm_next;
-  double secs, time;
-  Function *task = 0;
-  Symbol *s;
-  Operand op;
-  int typeID;
-  long index = -1;
-  char *name;
-
-
-  if (nargs != 2) YError("set_alarm takes exactly 2 arguments");
-  secs = YGetReal(sp - nargs + 1);
-  time = p_wall_secs() + secs;
-  s = sp - nargs + 2;
-  if (! s->ops) YError("unexpected keyword argument");
-  typeID = s->ops->FormOperand(s, &op)->ops->typeID;
-  if (typeID == T_STRING) {
-    if (op.type.dims) YError("expecting scalar string argument");
-    name = *(char **)op.value;
-    check_symbol_name(name);
-    index = Globalize(name, 0L);
-  } else if (typeID == T_FUNCTION || typeID == T_BUILTIN) {
-    task = (Function *)s->value.db;
-  } else {
-    YError("expecting function or function name");
-  }
-
-  if (! alarm_free) {
-    int i, n = 8;
-    alarm_context_t *new = p_malloc(n*sizeof(alarm_context_t));
-    new[--n].next = 0;
-    for (i=0 ; i<n ; ++i) new[i].next = &new[i + 1];
-    alarm_free = new;
-  }
-  this = alarm_free;
-  this->index = index;
-  this->task = 0;
-  this->time = time;
-  /* insert THIS into alarm_next list, kept in order of time */
-  while (next && next->time <= time) {
-    prev = &next->next;
-    next = next->next;
-  }
-  alarm_free = alarm_free->next;
-  this->next = next;
-  *prev = this;
-
-  if (task) this->task = Ref(task);
-
-  p_set_alarm(secs, alarm_callback, this);
-  PushDoubleValue(time);
-}
-
 /*---------------------------------------------------------------------------*/
 /* DATA ENCODING */
 
@@ -952,105 +674,6 @@ void Y_insure_temporary(int argc)
   }
 }
 
-/*---------------------------------------------------------------------------*/
-/* OBJECTS PROPERTIES */
-
-
-#if 0
-/* The function get_info sets members of the structure pointed by TYPE and
-   returns NULL, or sets type->base to NULL and returns address of
-   DataBlock to non-Array object. */
-static DataBlock *get_info(Member *type, Symbol *s);
-
-
-/* A stack Symbol can have 4 different values: intScalar, longScalar,
-   doubleScalar, datablockSym or referenceSym.  For an array, the datablock
-   may be of type lvalue. */
-
-static DataBlock *get_info(Member *type, Symbol *s)
-{
-  DataBlock *db = (DataBlock *)0;
-  for (;;) {
-    if (s->ops == &doubleScalar) {
-      type->base = &doubleStruct;
-      type->dims = (Dimension *)0;
-      type->number = 1;
-      break;
-    } else if (s->ops == &longScalar) {
-      type->base = &longStruct;
-      type->dims = (Dimension *)0;
-      type->number = 1;
-      break;
-    } else if (s->ops == &intScalar) {
-      type->base = &intStruct;
-      type->dims = (Dimension *)0;
-      type->number = 1;
-      break;
-    } else if (s->ops == &dataBlockSym) {
-      db = s->value.db;
-      if (db->ops == &lvalueOps) {
-        LValue *lvalue = (LValue *)db;
-        type->base = lvalue->type.base;
-        type->dims = lvalue->type.dims;
-        type->number = lvalue->type.number;
-      } else if (db->ops->isArray) {
-        Array *array = (Array *)db;
-        type->base = array->type.base;
-        type->dims = array->type.dims;
-        type->number = array->type.number;
-      } else {
-        type->base = 0;
-        type->dims = (Dimension *)0;
-        type->number = 0;
-      }
-      break;
-    } else if (s->ops == &referenceSym) {
-      s = &globTab[s->index];
-    } else {
-      YError("unexpected keyword argument");
-    }
-  }
-  return (type->base ? 0 : db);
-}
-
-static int get_dims(Symbol *s, Dimension **dims);
-/* Gets the dimension list of stack symbol S, taking care of L-values and
-   of following references, and returns true for array and false
-   otherwise. */
-
-static int get_dims(Symbol *s, Dimension **dims)
-{
-  for (;;) {
-    if (s->ops == &dataBlockSym) {
-      DataBlock *db = s->value.db;
-      if (db->ops == &lvalueOps) {
-        LValue *lvalue = (LValue *)db;
-        *dims = lvalue->type.dims;
-	return 1; /* an L-value is always an array, see is_array */
-      } else if (db->ops->isArray) {
-        Array *array = (Array *)db;
-        *dims = array->type.dims;
-        return 1;
-      } else {
-        *dims = (Dimension *)0;
-        return 0;
-      }
-    } else if (s->ops == &referenceSym) {
-      s = &globTab[s->index];
-    } else if (s->ops != (OpTable *)0) {
-      /* Must be one of: intScalar, longScalar, or doubleScalar. */
-      *dims = (Dimension *)0;
-      return 1;
-    } else {
-      /* keyword */
-      *dims = (Dimension *)0;
-      return 0;
-    }
-  }
-}
-
-#endif
-
 /*---------------------------------------------------------------------------*/
 /* SMOOTHING */
 
@@ -1066,8 +689,8 @@ void Y_smooth3(int argc)
   long which = 0; /* avoid compiler warning */
   Symbol *stack;
   Dimension *dims;
-  int nparsed=0;
-  double p25=0.25, p50=0.50, p75=0.75;
+  int nparsed = 0;
+  double p25 = 0.25, p50 = 0.50, p75 = 0.75;
 
   for (stack=sp-argc+1 ; stack<=sp ; ++stack) {
     if (stack->ops) {
