@@ -1,43 +1,54 @@
 /*
- * yeti_sparse.c --
+ * yeti_sparse.c -
  *
- *	Implement sparse matrix in Yorick.
+ * Implement sparse matrix in Yorick.
  *
  *-----------------------------------------------------------------------------
  *
- *	Copyright (C) 2005-2007 Eric Thibaut.
+ * Copyright (C) 1996-2010 Eric Thiébaut <thiebaut@obs.univ-lyon1.fr>
  *
- *	This file is part of Yeti.
+ * This software is governed by the CeCILL-C license under French law and
+ * abiding by the rules of distribution of free software.  You can use, modify
+ * and/or redistribute the software under the terms of the CeCILL-C license as
+ * circulated by CEA, CNRS and INRIA at the following URL
+ * "http://www.cecill.info".
  *
- *	Yeti is  free software;  you can redistribute  it and/or  modify it
- *	under  the terms of  the GNU  General Public  License version  2 as
- *	published by the Free Software Foundation.
+ * As a counterpart to the access to the source code and rights to copy,
+ * modify and redistribute granted by the license, users are provided only
+ * with a limited warranty and the software's author, the holder of the
+ * economic rights, and the successive licensors have only limited liability.
  *
- *	Yeti is distributed in the hope that it will be useful, but WITHOUT
- *	ANY WARRANTY; without even  the implied warranty of MERCHANTABILITY
- *	or FITNESS  FOR A PARTICULAR  PURPOSE.  See the GNU  General Public
- *	License for more details.
+ * In this respect, the user's attention is drawn to the risks associated with
+ * loading, using, modifying and/or developing or reproducing the software by
+ * the user in light of its specific status of free software, that may mean
+ * that it is complicated to manipulate, and that also therefore means that it
+ * is reserved for developers and experienced professionals having in-depth
+ * computer knowledge. Users are therefore encouraged to load and test the
+ * software's suitability as regards their requirements in conditions enabling
+ * the security of their systems and/or data to be ensured and, more
+ * generally, to use and operate it in the same conditions as regards
+ * security.
  *
- *	You should have  received a copy of the  GNU General Public License
- *	along with  Yeti (file "COPYING"  in the top source  directory); if
- *	not, write to  the Free Software Foundation, Inc.,  51 Franklin St,
- *	Fifth Floor, Boston, MA 02110-1301 USA
+ * The fact that you are presently reading this means that you have had
+ * knowledge of the CeCILL-C license and that you accept its terms.
  *
  *-----------------------------------------------------------------------------
  *
- * History:
- *	$Id: yeti_sparse.c,v 1.3 2007/03/28 12:08:03 eric Exp eric $
- *	$Log: yeti_sparse.c,v $
- *	Revision 1.3  2007/03/28 12:08:03  eric
- *	 - A few minor fixes to avoid compiler warnings.
+ * $Id: yeti_sparse.c,v 1.4 2010/04/13 14:06:06 eric Exp $
+ * $Log: yeti_sparse.c,v $
+ * Revision 1.4  2010/04/13 14:06:06  eric
+ *  - Changed license.
  *
- *	Revision 1.2  2007/03/23 16:28:34  eric
- *	 - Restricted possible values for JOB/FLAGS in evaluation
- *	   of matrix products: must be 0 (default) for direct
- *	   product and 1 for transpose product.
+ * Revision 1.3	2007/03/28 12:08:03  eric
+ *  - A few minor fixes to avoid compiler warnings.
  *
- *	Revision 1.1  2006/07/19 14:53:11  eric
- *	Initial revision
+ * Revision 1.2	2007/03/23 16:28:34  eric
+ *  - Restricted possible values for JOB/FLAGS in evaluation
+ *    of matrix products: must be 0 (default) for direct
+ *    product and 1 for transpose product.
+ *
+ * Revision 1.1	2006/07/19 14:53:11  eric
+ * Initial revision
  */
 
 #include <stdlib.h>
@@ -631,7 +642,7 @@ void Y_mvmult(int argc)
     default:
       YError("expecting array of reals for the 'vector'");
       return; /* avoid compiler warnings */
-    }    
+    }
 
     /* Cleanup temporary dimension list. */
     dims = tmpDims;
@@ -648,7 +659,7 @@ void Y_mvmult(int argc)
     nx = ny = 1;
     if (flags) {
       /* Leading dimensions of A must match dimensions of X, trailing
-	 dimensions of A are the dimensions of Y. */      
+	 dimensions of A are the dimensions of Y. */
       for (i = 0 ; i < ndims_x ; ++i) {
 	if (dimlist_x[i] != dimlist_a[i]) goto bad_dim_list;
 	nx *= dimlist_x[i];
@@ -659,7 +670,7 @@ void Y_mvmult(int argc)
       }
     } else {
       /* Trailing dimensions of A must match dimensions of X, leading
-	 dimensions of A are the dimensions of Y. */      
+	 dimensions of A are the dimensions of Y. */
       for (i = 0 ; i < ndims_x ; ++i) {
 	if (dimlist_x[i] != dimlist_a[i + ndims_y]) goto bad_dim_list;
 	nx *= dimlist_x[i];
@@ -711,11 +722,13 @@ static size_t pack_dimlist(const Dimension *dims, size_t dimlist[],
   return n;
 }
 
-/*---------------------------------------------------------------------------*
- * Local Variables:                                                          *
- * mode: C                                                                   *
- * tab-width: 8                                                              *
- * fill-column: 75                                                           *
- * coding: latin-1                                                           *
- * End:                                                                      *
- *---------------------------------------------------------------------------*/
+/*
+ * Local Variables:
+ * mode: C
+ * tab-width: 8
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * fill-column: 78
+ * coding: utf-8
+ * End:
+ */
