@@ -1,45 +1,54 @@
 /*
- * yeti_utils.c --
+ * yeti_utils.c -
  *
- *	Routines to make the coding of built-in Yorick's functions easier.
+ * Routines to make the coding of built-in Yorick's functions easier.
  *
  *-----------------------------------------------------------------------------
  *
- *	Copyright (C) 1999-2006 Eric Thibaut.
+ * Copyright (C) 1996-2010 Eric Thiébaut <thiebaut@obs.univ-lyon1.fr>
  *
- *	This file is part of Yeti.
+ * This software is governed by the CeCILL-C license under French law and
+ * abiding by the rules of distribution of free software.  You can use, modify
+ * and/or redistribute the software under the terms of the CeCILL-C license as
+ * circulated by CEA, CNRS and INRIA at the following URL
+ * "http://www.cecill.info".
  *
- *	Yeti is  free software;  you can redistribute  it and/or  modify it
- *	under  the terms of  the GNU  General Public  License version  2 as
- *	published by the Free Software Foundation.
+ * As a counterpart to the access to the source code and rights to copy,
+ * modify and redistribute granted by the license, users are provided only
+ * with a limited warranty and the software's author, the holder of the
+ * economic rights, and the successive licensors have only limited liability.
  *
- *	Yeti is distributed in the hope that it will be useful, but WITHOUT
- *	ANY WARRANTY; without even  the implied warranty of MERCHANTABILITY
- *	or FITNESS  FOR A PARTICULAR  PURPOSE.  See the GNU  General Public
- *	License for more details.
+ * In this respect, the user's attention is drawn to the risks associated with
+ * loading, using, modifying and/or developing or reproducing the software by
+ * the user in light of its specific status of free software, that may mean
+ * that it is complicated to manipulate, and that also therefore means that it
+ * is reserved for developers and experienced professionals having in-depth
+ * computer knowledge. Users are therefore encouraged to load and test the
+ * software's suitability as regards their requirements in conditions enabling
+ * the security of their systems and/or data to be ensured and, more
+ * generally, to use and operate it in the same conditions as regards
+ * security.
  *
- *	You should have  received a copy of the  GNU General Public License
- *	along with  Yeti (file "COPYING"  in the top source  directory); if
- *	not, write to  the Free Software Foundation, Inc.,  51 Franklin St,
- *	Fifth Floor, Boston, MA 02110-1301 USA
+ * The fact that you are presently reading this means that you have had
+ * knowledge of the CeCILL-C license and that you accept its terms.
  *
  *-----------------------------------------------------------------------------
+ * $Id: yeti_utils.c,v 1.5 2010/04/13 14:06:06 eric Exp $
+ * $Log: yeti_utils.c,v $
+ * Revision 1.5  2010/04/13 14:06:06  eric
+ *  - Changed license.
  *
- * History:
- *	$Id: yeti_utils.c,v 1.4 2007/12/26 10:57:22 eric Exp $
- *	$Log: yeti_utils.c,v $
- *	Revision 1.4  2007/12/26 10:57:22  eric
- *	 - Cleanup code for management of dimension lists.
+ * Revision 1.4	 2007/12/26 10:57:22  eric
+ *  - Cleanup code for management of dimension lists.
  *
- *	Revision 1.3  2006/07/19 14:54:51  eric
- *	 - Copyright notice updated.
+ * Revision 1.3	 2006/07/19 14:54:51  eric
+ *  - Copyright notice updated.
  *
- *	Revision 1.2  2006/07/19 08:45:40  eric
- *	 - Changes for new Yorick API.
- *
- *	Revision 1.1  2005/05/24 13:26:40  eric
- *	Initial revision
+ * Revision 1.2	 2006/07/19 08:45:40  eric
+ *  - Changes for new Yorick API.
  *
+ * Revision 1.1	 2005/05/24 13:26:40  eric
+ * Initial revision
  */
 
 #include <string.h>
@@ -699,4 +708,13 @@ void *yeti_push_workspace(size_t nbytes)
   return (void *)((char *)PushDataBlock(ws) + extra);
 }
 
-/*---------------------------------------------------------------------------*/
+/*
+ * Local Variables:
+ * mode: C
+ * tab-width: 8
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * fill-column: 78
+ * coding: utf-8
+ * End:
+ */
